@@ -24,7 +24,7 @@ Test::MockFile::FileHandle - Provides a class for L<Test::MockFile> to tie to on
 
 =head1 VERSION
 
-Version 0.005
+Version 0.006
 
 =cut
 
@@ -281,7 +281,7 @@ sub DESTROY {
 =head2 EOF
 
 This method will be called when the eof function is called.
-Based on C<$self->{'tell'}>, we determine if we're at EOF.
+Based on C<$self-E<gt>{'tell'}>, we determine if we're at EOF.
 
 =cut
 
